% Aufgabe 2.6.4: Lineare Transformation
%    [dx,dy] = linTransf2( w, v, t )
%    w : Drehwinkel im Bogenmaß
%    v : der zu drehende Vektor
%    t : Verschiebungsvektor
%    2. Variante: erst verschieben und dann drehen
function [dx,dy] = linTransf2( w, v, t )
    A(1,1) =   cos(w);
    A(1,2) = - sin(w);
    A(2,1) =   sin(w);
    A(2,2) =   cos(w);
    
    % erst verschieben und dann drehen
    d = A * (v + t);
    dx = d(1);
    dy = d(2);
end